from python_helper import Constant as c

URI_TERM = 'health'
URI = f'{c.SLASH}{URI_TERM}'
